# Filters added to this controller apply to all controllers in the application.
# Likewise, all the methods added will be available for all controllers.

class ApplicationController < ActionController::Base
  helper :all
  helper_method :current_user_session, :current_user
  filter_parameter_logging :password, :password_confirmation
  before_filter :set_current_user
  # filter_access_to [:assume_user, :return_to_admin], :require => :god

  # ensure_application_is_installed_by_facebook_user
  filter_parameter_logging :fb_sig_friends
  
  def permission_denied
    flash[:notice] = "You do not allowed to access to view that page"
    redirect_back_or_default root_url
  end
  
  protected
    def set_current_user
      Authorization.current_user = current_user
    end
  
    # Set session to another user.  Only available to admins
    def assume_user(new_user)
      return unless current_user && current_user.admin? && !new_user.admin?
      session[:admin_id] = current_user.id
      UserSession.create(new_user, true)
    end

    def return_to_admin
      unless current_user && !session[:admin_id].nil? && !current_user.admin?
        redirect_to login_path
        return
      end

      admin = User.find(session[:admin_id])
      if admin && admin.admin?
        session[:admin_id] = nil
        UserSession.create(admin, true)
        redirect_to user_path(admin)
      else
        current_user_session.destroy
        redirect_to login_path
      end
    end
   
  private
    def current_user_session
      return @current_user_session if defined?(@current_user_session)
      @current_user_session = UserSession.find
    end
    
    def current_user
      return @current_user if defined?(@current_user)
      @current_user = current_user_session && current_user_session.record
    end
    
    def store_location
      session[:return_to] = request.request_uri
    end
    
    def redirect_back_or_default(default)
      redirect_to(session[:return_to] || default)
      session[:return_to] = nil
    end
end
