class User < ActiveRecord::Base
  
  acts_as_authentic do |c|
    c.perishable_token_valid_for = 60.minutes
  end
  
  def before_connect(facebood_session)
    self.first_name = facebood_session.user.first_name
    self.last_name = facebood_session.user.last_name    
  end
  
  # activity tracker
  tracks_unlinked_activities [:updated_profile_image]  
  # messaging
  has_private_messages
  # User Profile image
  has_attached_file :avatar, 
                    :default_url => "/images/defaults/avatar_:style.jpg",
                    :styles => { 
                      :large => ["600x600>", :jpg], 
                      :medium => ["300x300>", :jpg], 
                      :thumb => ["100x100>",:jpg] 
                    },
                    :processors => [:cropper]
  attr_accessor :crop_x, :crop_y, :crop_w, :crop_h                  
  after_update :reprocess_avatar, :if => :cropping?
  
  def cropping?
    !crop_x.blank? && !crop_y.blank? && !crop_w.blank? && !crop_h.blank?
  end                  
  
  def avatar_geometry(style = :original)
    @geometry ||= {}
    @geometry[style] ||= Paperclip::Geometry.from_file(avatar.path(style))
  end
  
  def deliver_password_reset_instructions!  
    reset_perishable_token!  
    Notifier.deliver_password_reset_instructions(self)  
  end

  def role_symbols
    [role.to_sym]
  end
  
  def admin?
    role_symbols.include? :admin
  end

  private
    def reprocess_avatar
      avatar.reprocess!
    end
  
end
